@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for qldb service client
 
@@ -10,11 +11,12 @@ Usage::
     client: QLDBClient = boto3.client("qldb")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type
+from datetime import datetime
+from typing import Any, Dict, List, Type
+
 from botocore.exceptions import ClientError as Boto3ClientError
+
 from mypy_boto3_qldb.type_defs import (
     CancelJournalKinesisStreamResponseTypeDef,
     CreateLedgerResponseTypeDef,
